﻿using Syncfusion.UI.Xaml.RichTextBoxAdv;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;

namespace RTESample
{
    /// <summary>
    /// Sample View Model class
    /// </summary>
    public class ViewModel : INotifyPropertyChanged
    {
        #region Field
        private string documentTitle;
        Dictionary<string, Stream> documents = null;
        DocumentAdv document = null;
        bool skipUpdating = false;
        #endregion

        #region Constructor
        /// <summary>
        /// Initializes a new instance of the <see cref="ViewModel"/> class.
        /// </summary>
        public ViewModel()
        {
            InitializeDocuments();
        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets or sets the document title.
        /// </summary>
        /// <value>
        /// The document title.
        /// </value>
        public string DocumentTitle
        {
            get
            {
                return documentTitle;
            }
            set
            {
                UpdateDocument();
                documentTitle = value;
                NotifyPropertyChanged("DocumentTitle");
            }
        }
        /// <summary>
        /// Gets the documents.
        /// </summary>
        /// <value>
        /// The documents.
        /// </value>
        public ICollection<string> Documents
        {
            get
            {
                return documents.Keys;
            }
        }
        /// <summary>
        /// Gets or sets the document.
        /// </summary>
        /// <value>
        /// The document.
        /// </value>
        public DocumentAdv Document
        {
            get
            {
                return document;
            }
            set
            {
                if (!skipUpdating)
                    UpdateDocument();
                document = value;
                NotifyPropertyChanged("Document");
            }
        }
        #endregion

        #region Event
        public event PropertyChangedEventHandler PropertyChanged;
        #endregion

        #region Implementation
        /// <summary>
        /// Notifies the property changed.
        /// </summary>
        /// <param name="propertyName">Name of the property.</param>
        private void NotifyPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            if (propertyName == "DocumentTitle")
            {
                skipUpdating = true;
                SfRichTextBoxAdv richTextBox = new SfRichTextBoxAdv();
                richTextBox.Load(documents[documentTitle], FormatType.Docx);
                Document = richTextBox.Document;
                skipUpdating = false;
            }
        }
        /// <summary>
        /// Initializes the documents.
        /// </summary>
        private void InitializeDocuments()
        {
            documents = new Dictionary<string, Stream>();
            Assembly assembly = typeof(MainPage).GetTypeInfo().Assembly;

            Stream stream = assembly.GetManifestResourceStream("RTESample.Assets.AdventureCycles.docx");
            documents.Add("AdventureCycles", stream);
            stream = assembly.GetManifestResourceStream("RTESample.Assets.GettingStarted.docx");
            documents.Add("GettingStarted", stream);
            stream = assembly.GetManifestResourceStream("RTESample.Assets.GiantPanda.docx");
            documents.Add("GiantPanda", stream);
            stream = assembly.GetManifestResourceStream("RTESample.Assets.MeetingMinutes.docx");
            documents.Add("MeetingMinutes", stream);
            DocumentTitle = "AdventureCycles";
        }
        /// <summary>
        /// Updates the document.
        /// </summary>
        /// <exception cref="System.NotImplementedException"></exception>
        private void UpdateDocument()
        {
            if (document != null)
            {
                SfRichTextBoxAdv richTextBox = new SfRichTextBoxAdv();
                richTextBox.Document = document;
                Stream stream = new MemoryStream();
                richTextBox.Save(stream, FormatType.Docx);
                documents[documentTitle] = stream;
            }
        }
        #endregion
    }
}
